@@ -1,9 +1,7 @@
-import twisted.internet.main
+from twisted.internet import reactor
 import twisted.spread.pb
 import McFoo.config
 
-import os
-
 class McFooClientSimple:
     stopping = 0
 
@@ -14,19 +12,23 @@ class McFooClientSimple:
         if password==None:
             password='guest'
 
+        self.user=user
+        self.password=password
         self.remote = None
+        self.connect()
+
+    def connect(self):
         twisted.spread.pb.connect(
             McFoo.config.store.host,
             McFoo.config.store.port,
-            user, password, "dj"
+            self.user, self.password, "dj"
             ).addCallbacks(self.handle_connect,
                            self.handle_failure)
 
-
     def handle_failure(self, message):
         if not self.stopping:
             print "Cannot contact DJ:", message
-            twisted.internet.main.shutDown()
+            reactor.stop()
 
     def handle_connect(self, perspective):
         perspective.broker.notifyOnDisconnect(self.handle_disconnect)
@@ -40,4 +42,9 @@ class McFooClientSimple:
         pass
 
     def __call__(self):
-        twisted.internet.main.run()
+        reactor.run()
+
+    def stop(self, *foo, **bar):
+        # you can give me extra args and I won't mind.
+        # useful for pb callbacks.
+        reactor.stop()
