@@ -2,7 +2,7 @@
 
 import McFoo.client
 import sys, os.path
-import twisted.internet.main
+from twisted.internet import reactor
 from twisted.python import usage
 
 class Options(usage.Options):
@@ -28,4 +28,4 @@ class McFooClientDelete(McFoo.client.McFooClientSimple):
 
     def handle_login(self, perspective):
         McFoo.client.McFooClientSimple.handle_login(self, perspective)
-        self.remote.callRemote("delete", self.ids).addCallback(twisted.internet.main.shutDown)
+        self.remote.callRemote("delete", self.ids).addCallback(self.stop)
