@@ -2,7 +2,7 @@
 
 import McFoo.client
 import sys, os.path
-import twisted.internet.main
+from twisted.internet import reactor
 from twisted.python import usage
 
 class Options(usage.Options):
@@ -25,4 +25,4 @@ class McFooClientJump(McFoo.client.McFooClientSimple):
 
     def handle_login(self, perspective):
         McFoo.client.McFooClientSimple.handle_login(self, perspective)
-        self.remote.callRemote("jump", self.jump).addCallback(twisted.internet.main.shutDown)
+        self.remote.callRemote("jump", self.jump).addCallback(self.stop)
